/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtSql.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qtsqlglobal.sip"
#include <qtsqlglobal.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqldriver.sip"
#include <qsqldriver.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlindex.sip"
#include <qsqlindex.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlrecord.sip"
#include <qsqlrecord.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlfield.sip"
#include <qsqlfield.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlresult.sip"
#include <qsqlresult.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlerror.sip"
#include <qsqlerror.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qmap.sip"
#include <qmap.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 275 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qhash.sip"
#include <qhash.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 579 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 630 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqltablemodel.sip"
#include <qsqltablemodel.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlrelationaltablemodel.sip"
#include <qsqlrelationaltablemodel.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qtsqlglobal.sip"
#include <qtsqlglobal.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 37 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqldatabase.sip"
#include <qsqldatabase.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlquery.sip"
#include <qsqlquery.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlquerymodel.sip"
#include <qsqlquerymodel.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlrelationaldelegate.sip"
#include <qsqlrelationaldelegate.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqlrelationaltablemodel.sip"
#include <qsqlrelationaltablemodel.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtSql[] = {
    'Q', 'S', 'q', 'l', 'R', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'T', 'a', 'b', 'l', 'e', 'M', 'o', 'd', 'e', 'l', ':', ':', 'J', 'o', 'i', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'q', 'l', ':', ':', 'N', 'u', 'm', 'e', 'r', 'i', 'c', 'a', 'l', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', ':', ':', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'Q', 'S', 'q', 'l', 'Q', 'u', 'e', 'r', 'y', ':', ':', 'B', 'a', 't', 'c', 'h', 'E', 'x', 'e', 'c', 'u', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 'S', 'q', 'l', 'T', 'a', 'b', 'l', 'e', 'M', 'o', 'd', 'e', 'l', ':', ':', 'E', 'd', 'i', 't', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 'e', 't', 'N', 'u', 'm', 'e', 'r', 'i', 'c', 'a', 'l', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    'u', 'n', 's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'F', 'r', 'o', 'm', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', ':', ':', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', ':', ':', 'D', 'r', 'i', 'v', 'e', 'r', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'q', 'l', 'F', 'i', 'e', 'l', 'd', ':', ':', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 's', 'u', 'l', 't', ':', ':', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 'S', 'y', 'n', 't', 'a', 'x', 0,
    's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'd', 'T', 'o', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'T', 'a', 'b', 'l', 'e', 'M', 'o', 'd', 'e', 'l', 0,
    'n', 'u', 'm', 'e', 'r', 'i', 'c', 'a', 'l', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'P', 'o', 'l', 'i', 'c', 'y', 0,
    's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'T', 'o', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'P', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', 0,
    'Q', 'M', 'a', 'p', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', '>', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'D', 'e', 'l', 'e', 'g', 'a', 't', 'e', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', 'C', 'r', 'e', 'a', 't', 'o', 'r', 'B', 'a', 's', 'e', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', ':', ':', 'D', 'b', 'm', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'q', 'l', 'E', 'r', 'r', 'o', 'r', ':', ':', 'E', 'r', 'r', 'o', 'r', 'T', 'y', 'p', 'e', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'a', 'g', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'D', 'r', 'o', 'p', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'E', 'd', 'i', 't', 'o', 'r', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'L', 'o', 'w', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'N', 'u', 'm', 'b', 'e', 'r', 's', 0,
    'Q', 'S', 'q', 'l', ':', ':', 'P', 'a', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 'F', 'l', 'a', 'g', 0,
    'i', 's', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'E', 's', 'c', 'a', 'p', 'e', 'd', 0,
    'r', 'o', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 0,
    'E', 'v', 'e', 'n', 't', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    'L', 'o', 'w', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'D', 'o', 'u', 'b', 'l', 'e', 0,
    'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'R', 'e', 's', 'u', 'l', 't', 'S', 'e', 't', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'I', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'R', 'o', 'w', 'F', 'r', 'o', 'm', 'T', 'a', 'b', 'l', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 'I', 'n', 't', 'o', 'T', 'a', 'b', 'l', 'e', 0,
    'L', 'o', 'w', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'I', 'n', 't', '3', '2', 0,
    'L', 'o', 'w', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 'I', 'n', 't', '6', '4', 0,
    'N', 'a', 'm', 'e', 'd', 'P', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', 0,
    'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'V', 'a', 'r', 'i', 'a', 'n', 't', '>', 0,
    'c', 'o', 'm', 'm', 'i', 't', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'D', 'r', 'i', 'v', 'e', 'r', 'A', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', 0,
    'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', 0,
    's', 'e', 't', 'C', 'o', 'n', 'n', 'e', 'c', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    's', 'e', 't', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'b', 'e', 'g', 'i', 'n', 'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'e', 'n', 'd', 'I', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'e', 'n', 'd', 'R', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'e', 's', 'c', 'a', 'p', 'e', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'R', 'o', 'w', 'I', 'n', 'T', 'a', 'b', 'l', 'e', 0,
    'B', 'a', 't', 'c', 'h', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', 0,
    'C', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'I', 'n', 's', 'e', 'r', 't', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'P', 'r', 'e', 'p', 'a', 'r', 'e', 'd', 'Q', 'u', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 'S', 'q', 'l', ':', ':', 'P', 'a', 'r', 'a', 'm', 'T', 'y', 'p', 'e', 0,
    'Q', 'S', 'q', 'l', ':', ':', 'T', 'a', 'b', 'l', 'e', 'T', 'y', 'p', 'e', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'U', 'p', 'd', 'a', 't', 'e', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'V', 'a', 'l', 'u', 'e', 's', 'A', 's', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'I', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'b', 'e', 'g', 'i', 'n', 'R', 'e', 's', 'e', 't', 'M', 'o', 'd', 'e', 'l', 0,
    'b', 'o', 'u', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'a', 'n', 'D', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 's', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'r', 'r', 'o', 'r', 'C', 'o', 'd', 'e', 0,
    'n', 'u', 'm', 'R', 'o', 'w', 's', 'A', 'f', 'f', 'e', 'c', 't', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'E', 'd', 'i', 't', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    's', 't', 'r', 'i', 'p', 'D', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 's', 0,
    'B', 'e', 'f', 'o', 'r', 'e', 'F', 'i', 'r', 's', 't', 'R', 'o', 'w', 0,
    'O', 'n', 'M', 'a', 'n', 'u', 'a', 'l', 'S', 'u', 'b', 'm', 'i', 't', 0,
    'Q', 'S', 'q', 'l', ':', ':', 'L', 'o', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'S', 'q', 'l', 'Q', 'u', 'e', 'r', 'y', 'M', 'o', 'd', 'e', 'l', 0,
    'Q', 'S', 'q', 'l', 'T', 'a', 'b', 'l', 'e', 'M', 'o', 'd', 'e', 'l', 0,
    'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'W', 'h', 'e', 'r', 'e', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'b', 'o', 'u', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 'N', 'a', 'm', 'e', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'O', 'p', 't', 'i', 'o', 'n', 's', 0,
    'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'N', 'a', 'm', 'e', 0,
    'd', 'r', 'a', 'w', 'D', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'r', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 'S', 't', 'a', 't', 'u', 's', 0,
    's', 'e', 't', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 'O', 'n', 'l', 'y', 0,
    'H', 'i', 'g', 'h', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    'O', 'n', 'F', 'i', 'e', 'l', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'S', 'i', 'm', 'p', 'l', 'e', 'L', 'o', 'c', 'k', 'i', 'n', 'g', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'b', 'i', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 'T', 'y', 'p', 'e', 0,
    'b', 'i', 'n', 'd', 'i', 'n', 'g', 'S', 'y', 'n', 't', 'a', 'x', 0,
    'c', 'l', 'o', 'n', 'e', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'd', 'e', 's', 't', 'r', 'o', 'y', 'E', 'd', 'i', 't', 'o', 'r', 0,
    'd', 'i', 's', 'p', 'l', 'a', 'y', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'e', 'n', 'd', 'I', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'e', 'n', 'd', 'R', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'e', 'n', 'd', 'R', 'e', 's', 'e', 't', 'M', 'o', 'd', 'e', 'l', 0,
    'e', 'x', 'e', 'c', 'u', 't', 'e', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    'f', 'e', 't', 'c', 'h', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'i', 's', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 'O', 'n', 'l', 'y', 0,
    'o', 'r', 'd', 'e', 'r', 'B', 'y', 'C', 'l', 'a', 'u', 's', 'e', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'l', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'C', 'u', 'r', 's', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'D', 'e', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', 0,
    's', 'e', 't', 'D', 'r', 'i', 'v', 'e', 'r', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'E', 'd', 'i', 't', 'o', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'H', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'K', 'e', 'y', 0,
    'A', 'f', 't', 'e', 'r', 'L', 'a', 's', 't', 'R', 'o', 'w', 0,
    'L', 'a', 's', 't', 'I', 'n', 's', 'e', 'r', 't', 'I', 'd', 0,
    'N', 'a', 'm', 'e', 'd', 'B', 'i', 'n', 'd', 'i', 'n', 'g', 0,
    'Q', 'S', 'q', 'l', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'y', 's', 't', 'e', 'm', 'T', 'a', 'b', 'l', 'e', 's', 0,
    'T', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 's', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'V', 'a', 'l', 'u', 'e', 's', 'A', 's', 'R', 'o', 'w', 's', 0,
    'a', 'd', 'd', 'B', 'i', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'D', 'e', 'l', 'e', 't', 'e', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'I', 'n', 's', 'e', 'r', 't', 0,
    'b', 'e', 'f', 'o', 'r', 'e', 'U', 'p', 'd', 'a', 't', 'e', 0,
    'c', 'a', 'n', 'F', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'E', 'd', 'i', 't', 'o', 'r', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'R', 'e', 's', 'u', 'l', 't', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 'N', 'a', 'm', 'e', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 'T', 'e', 'x', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'd', 'r', 'o', 'p', 'M', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'e', 'd', 'i', 't', 'S', 't', 'r', 'a', 't', 'e', 'g', 'y', 0,
    'h', 'a', 's', 'O', 'u', 't', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'i', 'n', 'd', 'e', 'x', 'I', 'n', 'Q', 'u', 'e', 'r', 'y', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'i', 's', 'D', 'e', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', 0,
    'l', 'a', 's', 't', 'I', 'n', 's', 'e', 'r', 't', 'I', 'd', 0,
    'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'M', 'o', 'd', 'e', 'l', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'O', 'p', 'e', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    's', 'e', 't', 'P', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'q', 'l', 'S', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 0,
    'F', 'i', 'n', 'i', 's', 'h', 'Q', 'u', 'e', 'r', 'y', 0,
    'M', 'S', 'S', 'q', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'M', 'y', 'S', 'q', 'l', 'S', 'e', 'r', 'v', 'e', 'r', 0,
    'O', 'n', 'R', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'O', 't', 'h', 'e', 'r', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'S', 'q', 'l', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 'D', 'b', 'm', 's', 0,
    'a', 'd', 'd', 'D', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'b', 'o', 'u', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'w', 'D', 'i', 's', 'p', 'l', 'a', 'y', 0,
    'e', 'd', 'i', 't', 'o', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'o', 'r', 'm', 'a', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'h', 'a', 's', 'C', 'h', 'i', 'l', 'd', 'r', 'e', 'n', 0,
    'i', 'n', 'd', 'e', 'x', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'i', 's', 'A', 'u', 't', 'o', 'V', 'a', 'l', 'u', 'e', 0,
    'i', 's', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', 0,
    'i', 's', 'O', 'p', 'e', 'n', 'E', 'r', 'r', 'o', 'r', 0,
    'p', 'r', 'i', 'm', 'e', 'I', 'n', 's', 'e', 'r', 't', 0,
    'q', 'u', 'e', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    's', 'a', 'v', 'e', 'P', 'r', 'e', 'p', 'a', 'r', 'e', 0,
    's', 'e', 't', 'H', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'J', 'o', 'i', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'P', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    's', 'e', 't', 'R', 'e', 'l', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 0,
    't', 'r', 'i', 'm', 'S', 't', 'r', 'i', 'n', 'g', 's', 0,
    'P', 'o', 's', 't', 'g', 'r', 'e', 'S', 'Q', 'L', 0,
    'Q', 'S', 'q', 'l', 'D', 'r', 'i', 'v', 'e', 'r', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    'Q', 'S', 'q', 'l', 'R', 'e', 's', 'u', 'l', 't', 0,
    'S', 'e', 'l', 'f', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'b', 'o', 'u', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 'r', 's', 'o', 'r', 'N', 'a', 'm', 'e', 0,
    'd', 'r', 'i', 'v', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'd', 'r', 'i', 'v', 'e', 'r', 'T', 'e', 'x', 't', 0,
    'f', 'e', 't', 'c', 'h', 'F', 'i', 'r', 's', 't', 0,
    'f', 'i', 'e', 'l', 'd', 'I', 'n', 'd', 'e', 'x', 0,
    'h', 'a', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'h', 'e', 'a', 'd', 'e', 'r', 'D', 'a', 't', 'a', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'n', 'e', 'x', 't', 'R', 'e', 's', 'u', 'l', 't', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'K', 'e', 'y', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    's', 'e', 't', 'S', 'q', 'l', 'T', 'y', 'p', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'A', 'l', 'l', 'T', 'a', 'b', 'l', 'e', 's', 0,
    'F', 'i', 'e', 'l', 'd', 'N', 'a', 'm', 'e', 0,
    'I', 'n', 'n', 'e', 'r', 'J', 'o', 'i', 'n', 0,
    'I', 'n', 't', 'e', 'r', 'b', 'a', 's', 'e', 0,
    'Q', 'S', 'q', 'l', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'S', 'q', 'l', 'F', 'i', 'e', 'l', 'd', 0,
    'Q', 'S', 'q', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    'Q', 'S', 'q', 'l', 'Q', 'u', 'e', 'r', 'y', 0,
    'Q', 'u', 'e', 'r', 'y', 'S', 'i', 'z', 'e', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'b', 'i', 'n', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'd', 'r', 'a', 'w', 'C', 'h', 'e', 'c', 'k', 0,
    'd', 'r', 'a', 'w', 'F', 'o', 'c', 'u', 's', 0,
    'e', 'r', 'r', 'o', 'r', 'C', 'o', 'd', 'e', 0,
    'e', 'x', 'e', 'c', 'B', 'a', 't', 'c', 'h', 0,
    'f', 'e', 't', 'c', 'h', 'L', 'a', 's', 't', 0,
    'f', 'e', 't', 'c', 'h', 'M', 'o', 'r', 'e', 0,
    'f', 'e', 't', 'c', 'h', 'N', 'e', 'x', 't', 0,
    'f', 'i', 'e', 'l', 'd', 'N', 'a', 'm', 'e', 0,
    'h', 'e', 'l', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'k', 'e', 'y', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'l', 'a', 's', 't', 'E', 'r', 'r', 'o', 'r', 0,
    'l', 'a', 's', 't', 'Q', 'u', 'e', 'r', 'y', 0,
    'm', 'i', 'm', 'e', 'T', 'y', 'p', 'e', 's', 0,
    'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 0,
    'r', 'e', 'v', 'e', 'r', 't', 'A', 'l', 'l', 0,
    'r', 'e', 'v', 'e', 'r', 't', 'R', 'o', 'w', 0,
    'r', 'o', 'l', 'e', 'N', 'a', 'm', 'e', 's', 0,
    's', 'e', 'l', 'e', 'c', 't', 'R', 'o', 'w', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 0,
    's', 'e', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    's', 'e', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'N', 'u', 'm', 'b', 'e', 'r', 0,
    's', 'e', 't', 'R', 'e', 'c', 'o', 'r', 'd', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 0,
    's', 'u', 'b', 'm', 'i', 't', 'A', 'l', 'l', 0,
    't', 'a', 'b', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'L', 'e', 'f', 't', 'J', 'o', 'i', 'n', 0,
    'O', 'p', 't', 'i', 'o', 'n', 'a', 'l', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'c', 'o', 'n', 't', 'a', 'i', 'n', 's', 0,
    'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 0,
    'd', 'b', 'm', 's', 'T', 'y', 'p', 'e', 0,
    'h', 'o', 's', 't', 'N', 'a', 'm', 'e', 0,
    'i', 's', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'i', 's', 'S', 'e', 'l', 'e', 'c', 't', 0,
    'i', 't', 'e', 'm', 'D', 'a', 't', 'a', 0,
    'm', 'i', 'm', 'e', 'D', 'a', 't', 'a', 0,
    'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 0,
    'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', 0,
    'r', 'o', 'l', 'l', 'b', 'a', 'c', 'k', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'Q', 'u', 'e', 'r', 'y', 0,
    's', 'e', 't', 'T', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'u', 's', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'U', 'n', 'i', 'c', 'o', 'd', 'e', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'd', 'r', 'i', 'v', 'e', 'r', 's', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'i', 's', 'D', 'i', 'r', 't', 'y', 0,
    'i', 's', 'E', 'm', 'p', 't', 'y', 0,
    'i', 's', 'V', 'a', 'l', 'i', 'd', 0,
    'o', 'p', 't', 'i', 'o', 'n', 's', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 0,
    'r', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'N', 'u', 'l', 'l', 0,
    's', 'e', 't', 'O', 'p', 'e', 'n', 0,
    's', 'e', 't', 'P', 'o', 'r', 't', 0,
    's', 'e', 't', 'S', 'o', 'r', 't', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    's', 'i', 'b', 'l', 'i', 'n', 'g', 0,
    'B', 'i', 'n', 'a', 'r', 'y', 0,
    'O', 'r', 'a', 'c', 'l', 'e', 0,
    'S', 'Q', 'L', 'i', 't', 'e', 0,
    'S', 'y', 'b', 'a', 's', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'p', 'p', 'e', 'n', 'd', 0,
    'c', 'o', 'm', 'm', 'i', 't', 0,
    'd', 'r', 'i', 'v', 'e', 'r', 0,
    'f', 'i', 'l', 't', 'e', 'r', 0,
    'f', 'i', 'n', 'i', 's', 'h', 0,
    'h', 'a', 'n', 'd', 'l', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'i', 's', 'O', 'p', 'e', 'n', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'n', 'u', 'm', 'b', 'e', 'r', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'c', 'o', 'r', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    'r', 'e', 's', 'u', 'l', 't', 0,
    'r', 'e', 'v', 'e', 'r', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 0,
    's', 'u', 'b', 'm', 'i', 't', 0,
    't', 'a', 'b', 'l', 'e', 's', 0,
    't', 'y', 'p', 'e', 'I', 'D', 0,
    'I', 'n', 'O', 'u', 't', 0,
    'V', 'i', 'e', 'w', 's', 0,
    'b', 'u', 'd', 'd', 'y', 0,
    'c', 'l', 'e', 'a', 'r', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'e', 'x', 'e', 'c', '_', 0,
    'f', 'e', 't', 'c', 'h', 0,
    'f', 'i', 'e', 'l', 'd', 0,
    'f', 'i', 'r', 's', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'i', 'n', 'd', 'e', 'x', 0,
    'm', 'a', 't', 'c', 'h', 0,
    'p', 'a', 'i', 'n', 't', 0,
    'q', 'u', 'e', 'r', 'y', 0,
    'r', 'e', 's', 'e', 't', 0,
    's', 'e', 't', 'A', 't', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'B', 'L', 'O', 'B', 0,
    'Q', 'S', 'q', 'l', 0,
    'd', 'a', 't', 'a', 0,
    'e', 'x', 'e', 'c', 0,
    'h', 'o', 's', 't', 0,
    'l', 'a', 's', 't', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    'n', 'e', 'x', 't', 0,
    'o', 'p', 'e', 'n', 0,
    'p', 'o', 'r', 't', 0,
    'r', 'o', 'l', 'e', 0,
    's', 'e', 'e', 'k', 0,
    's', 'i', 'z', 'e', 0,
    's', 'o', 'r', 't', 0,
    's', 'p', 'a', 'n', 0,
    's', 'w', 'a', 'p', 0,
    't', 'e', 'x', 't', 0,
    't', 'y', 'p', 'e', 0,
    'u', 's', 'e', 'r', 0,
    'D', 'B', '2', 0,
    'I', 'n', 0,
    'a', 't', 0,
    'd', 'b', 0,
};

::QSqlRecord sipVH_QtSql_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSqlRecord sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSqlRecord, &sipRes);

    return sipRes;
}

int sipVH_QtSql_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtSql_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

void sipVH_QtSql_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QVariant& a1, ::QSql::ParamType a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, new ::QSql::ParamType(a2), sipType_QSql_ParamType, SIP_NULLPTR);
}

void sipVH_QtSql_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QVariant& a1, ::QSql::ParamType a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iNN", a0, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, new ::QSql::ParamType(a2), sipType_QSql_ParamType, SIP_NULLPTR);
}

::QSqlTableModel* sipVH_QtSql_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QSqlTableModel* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QSqlTableModel, &sipRes);

    return sipRes;
}

void sipVH_QtSql_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QSqlRelation& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iN", a0, new ::QSqlRelation(a1), sipType_QSqlRelation, SIP_NULLPTR);
}

::QString sipVH_QtSql_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSql_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSqlRecord& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QSqlRecord(a0), sipType_QSqlRecord, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSql_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QSqlRecord& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iN", a0, new ::QSqlRecord(a1), sipType_QSqlRecord, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSql_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

void sipVH_QtSql_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QSqlTableModel::EditStrategy a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "F", a0, sipType_QSqlTableModel_EditStrategy);
}

void sipVH_QtSql_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtSql_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHelpEvent*a0, ::QAbstractItemView*a1, const ::QStyleOptionViewItem& a2, const ::QModelIndex& a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DDNN", a0, sipType_QHelpEvent, SIP_NULLPTR, a1, sipType_QAbstractItemView, SIP_NULLPTR, new ::QStyleOptionViewItem(a2), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSql_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0, ::QAbstractItemModel*a1, const ::QStyleOptionViewItem& a2, const ::QModelIndex& a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DDDN", a0, sipType_QEvent, SIP_NULLPTR, a1, sipType_QAbstractItemModel, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a2), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSql_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDN", a0, sipType_QWidget, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtSql_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, ::QAbstractItemModel*a1, const ::QModelIndex& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDN", a0, sipType_QWidget, SIP_NULLPTR, a1, sipType_QAbstractItemModel, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtSql_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, const ::QModelIndex& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QWidget, SIP_NULLPTR, new ::QModelIndex(a1), sipType_QModelIndex, SIP_NULLPTR);
}

::QWidget* sipVH_QtSql_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2)
{
    ::QWidget* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DDN", a0, sipType_QWidget, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWidget, &sipRes);

    return sipRes;
}

::QSize sipVH_QtSql_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QStyleOptionViewItem& a0, const ::QModelIndex& a1)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DN", const_cast< ::QStyleOptionViewItem *>(&a0), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a1), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

void sipVH_QtSql_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDN", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);
}

void sipVH_QtSql_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QRect& a2, ::Qt::CheckState a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDNF", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QRect(a2), sipType_QRect, SIP_NULLPTR, a3, sipType_Qt_CheckState);
}

void sipVH_QtSql_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QRect& a2, const ::QPixmap& a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDNN", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QRect(a2), sipType_QRect, SIP_NULLPTR, new ::QPixmap(a3), sipType_QPixmap, SIP_NULLPTR);
}

void sipVH_QtSql_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QRect& a2, const ::QString& a3)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDNN", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QRect(a2), sipType_QRect, SIP_NULLPTR, new ::QString(a3), sipType_QString, SIP_NULLPTR);
}

void sipVH_QtSql_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QRect& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DDN", a0, sipType_QPainter, SIP_NULLPTR, const_cast< ::QStyleOptionViewItem *>(&a1), sipType_QStyleOptionViewItem, SIP_NULLPTR, new ::QRect(a2), sipType_QRect, SIP_NULLPTR);
}

bool sipVH_QtSql_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, int a2, const ::QModelIndex& a3, int a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiiNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, a2, new ::QModelIndex(a3), sipType_QModelIndex, SIP_NULLPTR, a4);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QHash<int, ::QByteArray> sipVH_QtSql_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QHash<int, ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QHash_1800_0100QByteArray, &sipRes);

    return sipRes;
}

::QSize sipVH_QtSql_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

::QModelIndexList sipVH_QtSql_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1, const ::QVariant& a2, int a3, ::Qt::MatchFlags a4)
{
    ::QModelIndexList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NiNiN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3, new ::Qt::MatchFlags(a4), sipType_Qt_MatchFlags, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QModelIndex, &sipRes);

    return sipRes;
}

void sipVH_QtSql_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::SortOrder a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_Qt_SortOrder);
}

::Qt::ItemFlags sipVH_QtSql_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::Qt::ItemFlags sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_Qt_ItemFlags, &sipRes);

    return sipRes;
}

void sipVH_QtSql_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);
}

bool sipVH_QtSql_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::Qt::DropActions sipVH_QtSql_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::Qt::DropActions sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_Qt_DropActions, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMimeData*a0, ::Qt::DropAction a1, int a2, int a3, const ::QModelIndex& a4)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DFiiN", const_cast< ::QMimeData *>(a0), sipType_QMimeData, SIP_NULLPTR, a1, sipType_Qt_DropAction, a2, a3, new ::QModelIndex(a4), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QMimeData* sipVH_QtSql_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndexList& a0)
{
    ::QMimeData* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndexList(a0), sipType_QList_0100QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QMimeData, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const QMap<int, ::QVariant>& a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new QMap<int, ::QVariant>(a1), sipType_QMap_1800_0100QVariant, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

QMap<int, ::QVariant> sipVH_QtSql_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    QMap<int, ::QVariant> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QMap_1800_0100QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, const ::QVariant& a2, int a3)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFNi", a0, a1, sipType_Qt_Orientation, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtSql_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::Qt::Orientation a1, int a2)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iFi", a0, a1, sipType_Qt_Orientation, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, const ::QVariant& a1, int a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNi", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtSql_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0, int a1)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Ni", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

int sipVH_QtSql_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QModelIndex sipVH_QtSql_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QModelIndex& a0)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QModelIndex(a0), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

::QModelIndex sipVH_QtSql_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1, const ::QModelIndex& a2)
{
    ::QModelIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "iiN", a0, a1, new ::QModelIndex(a2), sipType_QModelIndex, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QModelIndex, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, ::QSqlDriver::IdentifierType a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QString(a0), sipType_QString, SIP_NULLPTR, a1, sipType_QSqlDriver_IdentifierType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QStringList sipVH_QtSql_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSql_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSqlError& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QSqlError(a0), sipType_QSqlError, SIP_NULLPTR);
}

void sipVH_QtSql_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

bool sipVH_QtSql_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QString& a1, const ::QString& a2, const ::QString& a3, int a4, const ::QString& a5)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NNNNiN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR, new ::QString(a2), sipType_QString, SIP_NULLPTR, new ::QString(a3), sipType_QString, SIP_NULLPTR, a4, new ::QString(a5), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QSqlResult* sipVH_QtSql_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSqlResult* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSqlResult, &sipRes);

    return sipRes;
}

void sipVH_QtSql_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtSql_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QSqlDriver::DriverFeature a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QSqlDriver_DriverFeature);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QVariant sipVH_QtSql_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

::QString sipVH_QtSql_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QSqlDriver::StatementType a0, const ::QString& a1, const ::QSqlRecord& a2, bool a3)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FNNb", a0, sipType_QSqlDriver_StatementType, new ::QString(a1), sipType_QString, SIP_NULLPTR, new ::QSqlRecord(a2), sipType_QSqlRecord, SIP_NULLPTR, a3);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QString sipVH_QtSql_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, ::QSqlDriver::IdentifierType a1)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NF", new ::QString(a0), sipType_QString, SIP_NULLPTR, a1, sipType_QSqlDriver_IdentifierType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QString sipVH_QtSql_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QSqlField& a0, bool a1)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "Nb", new ::QSqlField(a0), sipType_QSqlField, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QSqlRecord sipVH_QtSql_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QSqlRecord sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSqlRecord, &sipRes);

    return sipRes;
}

::QSqlIndex sipVH_QtSql_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    ::QSqlIndex sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSqlIndex, &sipRes);

    return sipRes;
}

::QStringList sipVH_QtSql_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QSql::TableType a0)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QSql_TableType);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

bool sipVH_QtSql_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSql_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtSql_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtSql_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtSql_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtSql_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtSql_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

::QSqlDriver* sipVH_QtSql_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSqlDriver* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QSqlDriver, &sipRes);

    return sipRes;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QSqlDriver(void **);}
static const sipTypeDef *sipSubClass_QSqlDriver(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtSql/qsqldriver.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QSqlQueryModel, &sipType_QSqlQueryModel, 3, 1},
        {sipName_QSqlRelationalDelegate, &sipType_QSqlRelationalDelegate, -1, 2},
        {sipName_QSqlDriver, &sipType_QSqlDriver, -1, -1},
        {sipName_QSqlTableModel, &sipType_QSqlTableModel, 4, -1},
        {sipName_QSqlRelationalTableModel, &sipType_QSqlRelationalTableModel, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtSql/sipQtSqlcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QSql_ParamTypeFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_QSql_ParamTypeFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSql::ParamTypeFlag a0;
        ::QSql::ParamType* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QSql_ParamTypeFlag, &a0, sipType_QSql_ParamType, &a1, &a1State))
        {
            ::QSql::ParamType*sipRes;

            sipRes = new ::QSql::ParamType((a0 | *a1));
            sipReleaseType(a1, sipType_QSql_ParamType, a1State);

            return sipConvertFromNewType(sipRes, sipType_QSql_ParamType, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QSql_ParamTypeFlag[] = {
    {(void *)slot_QSql_ParamTypeFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSql__Location, SIP_NULLPTR, 0}, sipNameNr_Location, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSql__NumericalPrecisionPolicy, SIP_NULLPTR, 0}, sipNameNr_NumericalPrecisionPolicy, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSql__ParamTypeFlag, SIP_NULLPTR, 0}, sipNameNr_ParamTypeFlag, 1, slots_QSql_ParamTypeFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSql__TableType, SIP_NULLPTR, 0}, sipNameNr_TableType, 1, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlDriver__DbmsType, SIP_NULLPTR, 0}, sipNameNr_DbmsType, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlDriver__DriverFeature, SIP_NULLPTR, 0}, sipNameNr_DriverFeature, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlDriver__IdentifierType, SIP_NULLPTR, 0}, sipNameNr_IdentifierType, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlDriver__NotificationSource, SIP_NULLPTR, 0}, sipNameNr_NotificationSource, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlDriver__StatementType, SIP_NULLPTR, 0}, sipNameNr_StatementType, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlError__ErrorType, SIP_NULLPTR, 0}, sipNameNr_ErrorType, 15, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlField__RequiredStatus, SIP_NULLPTR, 0}, sipNameNr_RequiredStatus, 17, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlQuery__BatchExecutionMode, SIP_NULLPTR, 0}, sipNameNr_BatchExecutionMode, 20, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlRelationalTableModel__JoinMode, SIP_NULLPTR, 0}, sipNameNr_JoinMode, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlResult__BindingSyntax, SIP_NULLPTR, 0}, sipNameNr_BindingSyntax, 28, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QSqlTableModel__EditStrategy, SIP_NULLPTR, 0}, sipNameNr_EditStrategy, 30, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtSql[] = {
    &sipTypeDef_QtSql_QMap_0100QString_0100QVariant.mtd_base,
    &sipTypeDef_QtSql_QSql.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtSql_QSql_ParamType.ctd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtSql_QSqlDatabase.ctd_base,
    &sipTypeDef_QtSql_QSqlDriver.ctd_base,
    &enumTypes[4].etd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &enumTypes[7].etd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtSql_QSqlDriverCreatorBase.ctd_base,
    &sipTypeDef_QtSql_QSqlError.ctd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtSql_QSqlField.ctd_base,
    &enumTypes[10].etd_base,
    &sipTypeDef_QtSql_QSqlIndex.ctd_base,
    &sipTypeDef_QtSql_QSqlQuery.ctd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtSql_QSqlQueryModel.ctd_base,
    &sipTypeDef_QtSql_QSqlRecord.ctd_base,
    &sipTypeDef_QtSql_QSqlRelation.ctd_base,
    &sipTypeDef_QtSql_QSqlRelationalDelegate.ctd_base,
    &sipTypeDef_QtSql_QSqlRelationalTableModel.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtSql_QSqlResult.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtSql_QSqlTableModel.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtSql_QVector_0100QVariant.mtd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtSql_QtCore[] = {
    {"QAbstractItemModel"},
    {"QAbstractTableModel"},
    {"QChildEvent"},
    {"QEvent"},
    {"QHash<int,QByteArray>"},
    {"QList<QModelIndex>"},
    {"QMap<int,QVariant>"},
    {"QMetaMethod"},
    {"QMimeData"},
    {"QModelIndex"},
    {"QObject"},
    {"QRect"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {"QVariant::Type"},
    {"Qt::CheckState"},
    {"Qt::DropAction"},
    {"Qt::DropActions"},
    {"Qt::ItemFlags"},
    {"Qt::MatchFlags"},
    {"Qt::Orientation"},
    {"Qt::SortOrder"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtSql_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtSql_QtGui[] = {
    {"QHelpEvent"},
    {"QPainter"},
    {"QPixmap"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtSql_QtWidgets[] = {
    {"QAbstractItemDelegate"},
    {"QAbstractItemView"},
    {"QItemDelegate"},
    {"QStyleOptionViewItem"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtSql_QtCore, sipImportedVirtErrorHandlers_QtSql_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtSql_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWidgets", sipImportedTypes_QtSql_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QSqlDriver, {10, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtSql = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtSql,
    0,
    sipStrings_QtSql,
    importsTable,
    SIP_NULLPTR,
    33,
    sipExportedTypes_QtSql,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtSql;

sip_qt_metaobject_func sip_QtSql_qt_metaobject;
sip_qt_metacall_func sip_QtSql_qt_metacall;
sip_qt_metacast_func sip_QtSql_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtSql()
#else
PyMODINIT_FUNC PyInit_QtSql()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtSql",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtSql = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtSql == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtSql, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtSql_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtSql_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtSql_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtSql_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtSql, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
